* Replication file for Croco and Weeks (2016), "War Outcomes and Leader Tenure," World Politics
* Please contact the authors with any questions (scroco@umd.edu or jweeks@wisc.edu)

**************************************
************** ANALYSIS **************
**************************************

use CrocoWeeks2016WP.dta, clear


* MODEL 1 - Dems only, with culp vars 
* test for violations of PH
stcox founder civilwar growth age0 ///
ongoingwar_culp ongoingwar_notculp ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if democracy==1, efron cluster(ccode)
estat phtest, detail

* Run MODEL 1 with PH corrections 
stcox founder founderxt civilwar growth age0 ///
ongoingwar_culp ongoingwar_culpxt ongoingwar_notculp ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if democracy==1, efron cluster(ccode)
estat phtest, detail
outreg2 using table1, label eform replace dec(2)

* for discussion in text
browse if democracy==1 & dwin_culp==1 & e(sample)
browse if democracy==1 & dwin_notculp==1 & e(sample)


* MODEL 1 without presidential systems
* MODEL 1b - Dems only, with culp vars, no presidential systems
stcox founder civilwar growth age0 ///
ongoingwar_culp ongoingwar_notculp ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if democracy==1 & dempres!=1, efron cluster(ccode)
estat phtest, detail

*  MODEL 1b with corrections
stcox founder civilwar growth age0 ///
ongoingwar_culp ongoingwar_culpxt ongoingwar_notculp ongoingwar_notculpxt ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if democracy==1 & dempres!=1, efron cluster(ccode)
estat phtest, detail

testparm dwin_culp 
testparm ddraw_culp 
testparm dlose_culp 
testparm dwin_culp dlose_culp, equal 
testparm dwin_culp ddraw_culp, equal 
testparm dlose_culp ddraw_culp, equal 
testparm dwin_culp dwin_notculp, equal 


************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************

* MODEL 2 - Auts only, with culp vars
* Test for violations of PH 
stcox founder ongoingwar_culp ongoingwar_notculp civilwar growth age0  ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if democracy==0, efron cluster(ccode)
estat phtest, detail

*  MODEL 2 with log(t) corrections
stcox founder* ongoingwar_culp ongoingwar_notculp civilwar growth age0  ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if democracy==0, efron cluster(ccode)
estat phtest, detail
outreg2 using table1, label eform append dec(2)

testparm dwin_culp 
testparm ddraw_culp 
testparm dlose_culp 
testparm dwin_culp dlose_culp, equal 
testparm dwin_culp ddraw_culp, equal 
testparm dlose_culp ddraw_culp, equal 
testparm dwin_culp dwin_notculp, equal 

* for discussion
browse if dwin_notculp==1 & e(sample)
browse if ddraw_notculp==1 & e(sample)


************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************

* MODEL 3 - Weak inst, with culp vars
* Test for violations of PH 
stcox founder ongoingwar_culp ongoingwar_notculp civilwar growth age0  ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if lowconstraint==1 & year>1945, efron cluster(ccode)
estat phtest, detail // fixing the civil war PH violation doesn't really make a difference, just creates new violations. Doesn't change main vars.

* MODEL 3 with  corrections
* see above
outreg2 using table1, label eform append dec(2)

testparm dwin_culp 
testparm ddraw_culp 
testparm dlose_culp 
testparm dwin_culp dlose_culp, equal 
testparm dwin_culp ddraw_culp, equal 
testparm dlose_culp ddraw_culp, equal 
testparm dlose_culp dlose_notculp, equal 

* for discussion
browse if ongoingwar_notculp==1 & e(sample)

************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************

* MODEL 4 - Strong inst, with culp vars
* Test for violations of PH 
stcox founder ongoingwar_culp ongoingwar_notculp civilwar growth age0 ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if lowconstraint==0 & democracy==0 & year>1945, efron cluster(ccode)
estat phtest, detail

* MODEL 4 with corrections 
stcox founder* ongoingwar_culp ongoingwar_notculp civilwar growth age0 ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if lowconstraint==0 & democracy==0 & year>1945, efron cluster(ccode)
estat phtest, detail
outreg2 using table1, label eform append dec(2)

testparm dwin_culp 
testparm ddraw_culp 
testparm dlose_culp 
testparm dwin_culp dlose_culp, equal 
testparm dwin_culp ddraw_culp, equal 
testparm dlose_culp ddraw_culp, equal 
testparm dlose_culp dlose_notculp, equal 


************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************
* FIGURE 2
************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************

*******************************************
* DEMOCRACIES
*******************************************

* rerun Model 1 with corrections
stcox founder founderxt civilwar growth age0 ///
ongoingwar_culp ongoingwar_culpxt ongoingwar_notculp ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if democracy==1, efron cluster(ccode)

* first calc cumhaz at peace at start of tenure
* stcurve WITHOUT arguments plots the function at the mean values in the dataset
stcurve, haz at(ongoingwar_culp=0 ongoingwar_culpxt=0 ongoingwar_notculp=0 dwin_culp=0 ddraw_culp=0 dlose_culp=0 ///
dwin_notculp=0 ddraw_notculp=0 dlose_notculp=0) width(20) ///
outfile(stcurvedem, replace)

stcurve, cumhaz at(ongoingwar_culp=0 ongoingwar_culpxt=0 ongoingwar_notculp=0 dwin_culp=0 ddraw_culp=0 dlose_culp=0 ///
dwin_notculp=0 ddraw_notculp=0 dlose_notculp=0) ///
outfile(stcurvedemcumhaz, replace)

* now look at the output dataset
preserve
use "stcurvedem.dta", clear
tab _t if _t<2000, sum(haz) 
di 3*365
* use the average of the #s from 329 to 1076
di 730*(1/8)*(.00075977+  .00044232 + .00071472 + .00036291 +  .00065092 + .0005504 +  .00031854  +  .00085281) // approx 42.45% chance  of losing office over next 2 years (.42453059)

* now set dlose_culp=1
restore // added this
stcurve, haz at(ongoingwar_culp=0 ongoingwar_culpxt=0 ongoingwar_notculp=0 dwin_culp=0 ddraw_culp=0 dlose_culp=1 ///
dwin_notculp=0 ddraw_notculp=0 dlose_notculp=0) width(20) ///
outfile(stcurvedemlose, replace)
preserve
use "stcurvedemlose.dta", clear
tab _t if _t<2000, sum(haz) 

* use the average #s between 329 and 1092
di 730*(1/8)*(.00233071  + .00135866 + .00219457 + .00111414 + .00199739 + .00168916 + .00097772 + .00261511) // 1.3028182 accumulated hazard over next 2 years

di 1.3028182/.42453059 // here is our approx 3.07 hazard ratio
di 1.3028182-.42453059 // with a risk difference of 88 points

* now set dwin_culp=1
restore
stcurve, haz at(ongoingwar_culp=0 ongoingwar_culpxt=0 ongoingwar_notculp=0 dwin_culp=1 ddraw_culp=0 dlose_culp=0 ///
dwin_notculp=0 ddraw_notculp=0 dlose_notculp=0) width(20) ///
outfile(stcurvedemwin, replace)
preserve
use "stcurvedemwin.dta", clear
tab _t if _t<2000, sum(haz) 

* use the average #s between 329 and 1092
di 730*(1/8)*(.00034666 + .00020175  +  .00032603 +.00016555   + .00029697 +  .00025111 + .00014532 + .00038915 ) // .19368178 accumulated hazard over next 2 years

di .19368178/.42453059 // here is our approx .46 effect
di .19368178 - .42453059 // -.23084881

* now set ddraw_culp=0
restore
stcurve, haz at(ongoingwar_culp=0 ongoingwar_culpxt=0 ongoingwar_notculp=0 dwin_culp=0 ddraw_culp=1 dlose_culp=0 ///
dwin_notculp=0 ddraw_notculp=0 dlose_notculp=0) width(20) ///
outfile(stcurvedemdraw, replace)
preserve
use "stcurvedemdraw.dta", clear
tab _t if _t<2000, sum(haz) 

* use the average #s between 329 and 1092
di 730*(1/8)*( .00071576 + .00041669 +  .0006733 + .00034188 + .00061321 + .00051852 + .00030009 + .00080342) // .39993689 accumulated hazard over next 2 years

di .39993689/.42453059 // here is our approx 94 effect
di .39993689 - .42453059 // -.0245937


*******************************************
* ALL NONDEMOCRACIES
*******************************************

restore

* Model 2
stcox founder* ongoingwar_culp ongoingwar_notculp civilwar growth age0 ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if democracy==0, efron cluster(ccode)

* first calc cumhaz at peace 
stcurve, haz at(ongoingwar_culp=0 ongoingwar_notculp=0 dwin_culp=0 ddraw_culp=0 dlose_culp=0 ///
ddraw_notculp=0 dlose_notculp=0) width(20) ///
outfile(stcurveaut, replace)

* now look at the output dataset
preserve
use "stcurveaut.dta", clear
tab _t if _t<2000, sum(haz) 
di 3*365
* use the average #s between 422 and 983 [not exact, but ok
di 730*(1/5)*( .00046226  + .00037701 + .00037905   + .0004818 + .00037732 ) // approx .30330624 chance of losing office over next 2 years

* shortcuts to calculating w/d/l - multiply by coefficients
* Win
di .244223*.30330624

* Draw
di  1.225215*.30330624

* Lose
di 2.065816*.30330624


*******************************************
* NON-VULNERABLE AUTOCRATS
*******************************************

* rerun model 3
restore
stcox founder ongoingwar_culp ongoingwar_notculp civilwar growth age0  ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if lowconstraint==1 & year>1945, efron cluster(ccode)

* first calc cumhaz at peace 
stcurve, haz at(ongoingwar_culp=0 ongoingwar_notculp=0 dwin_culp=0 ddraw_culp=0 dlose_culp=0 ///
ddraw_notculp=0 dlose_notculp=0) width(20) ///
outfile(stcurvepers, replace)

* now look at the output dataset
preserve
use "stcurvepers.dta", clear
tab _t if _t<2000, sum(haz) 
di 3*365
* use the average #s between 380 and 1011 
di 730*(1/6)*( .00026157 + .00030175  + 0  +  .00011471   + .00011581  + .0002745 ) // .12998137 approx 13% chance of losing office over next 2 years

* shortcuts to calculating w/d/l - multiply by coefficients
* Win
di .1373372 *.12998137

* Draw
di  .5206511 *.12998137

* Lose
di 1.793886 *.12998137


*******************************************
* VULNERABLE AUTOCRATS
*******************************************

* rerun model 4
restore
stcox founder* ongoingwar_culp ongoingwar_notculp civilwar growth age0 ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if lowconstraint==0 & democracy==0 & year>1945, efron cluster(ccode)

* first calc cumhaz at peace 
stcurve, haz at( ongoingwar_culp=0 ongoingwar_notculp=0 dwin_culp=0 ddraw_culp=0 dlose_culp=0 ///
dlose_notculp=0 ) width(20) ///
outfile(stcurvenonpers, replace)

* now look at the output dataset
preserve
use "stcurvenonpers.dta", clear
tab _t if _t<2000, sum(haz) 
di 3*365
* use the average #s between 338 and 1105
di 730*(1/7)*(.00123941+  .0002667 +  .00018628+ .00035878  + .00050255  + .00034352+  .00002337 ) // approx .3045779 chance of losing office over next 2 years

* shortcuts to calculating w/d/l - multiply by coefficients
* Win
di .1638031 *.3045779 // .0498908
di .3045779-.0498908 // .2546871

* Draw
di 1.350701 *.3045779

* Lose
di  3.542362 *.3045779 // 1.0789252
di 1.0789252-.3045779

************************************************************************************************
************************************************************************************************
* ADDITIONAL TESTS (APPENDIX)
************************************************************************************************
************************************************************************************************

restore
* For reference:
* Model 1: baseline
stcox founder founderxt civilwar growth age0 ///
ongoingwar_culp ongoingwar_culpxt ongoingwar_notculp ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if democracy==1, efron cluster(ccode)
estat phtest, detail

* Model 2: baseline with log(t) corrections
stcox founder* ongoingwar_culp ongoingwar_notculp civilwar growth age0  ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if democracy==0, efron cluster(ccode)
estat phtest, detail

* Model 3: baseline [no corrections needed)
stcox founder ongoingwar_culp ongoingwar_notculp civilwar growth age0  ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if lowconstraint==1 & year>1945, efron cluster(ccode)
estat phtest, detail

* Model 4: baseline with corrections 
stcox founder* ongoingwar_culp ongoingwar_notculp civilwar growth age0 ///
dwin_culp ddraw_culp dlose_culp ///
dwin_notculp ddraw_notculp dlose_notculp if lowconstraint==0 & democracy==0 & year>1945, efron cluster(ccode)
estat phtest, detail


* WITH INTERSTATE WARS ONLY

* Model 1: interstate only
* without interactions for lose and draw
stcox founder founderxt civilwar growth age0 ///
ongoingwar_culp ongoingwar_culpxt ongoingwar_notculp ///
dwin_is_culp ddraw_is_culp  dlose_is_culp  ///
dwin_is_notculp ddraw_is_notculp dlose_is_notculp if democracy==1, efron cluster(ccode)
estat phtest, detail 
outreg2 using tableA1, label eform replace dec(2)

* Model 2: interstate only
stcox founder* ongoingwar_culp ongoingwar_notculp civilwar growth age0 ///
dwin_is_culp ddraw_is_culp dlose_is_culp ///
dwin_is_notculp ddraw_is_notculp dlose_is_notculp if democracy==0, efron cluster(ccode)
estat phtest, detail
outreg2 using tableA1, label eform append dec(2)

* Model 3: interstate only
stcox founder ongoingwar_culp ongoingwar_notculp civilwar growth age0 ///
dwin_is_culp ddraw_is_culp dlose_is_culp ///
dwin_is_notculp ddraw_is_notculp dlose_is_notculp if lowconstraint==1 & year>1945, efron cluster(ccode)
estat phtest, detail
outreg2 using tableA1, label eform append dec(2)

* Model 4: interstate only
stcox founder* ongoingwar_culp ongoingwar_notculp civilwar growth age0 ///
dwin_is_culp ddraw_is_culp dlose_is_culp ///
dwin_is_notculp ddraw_is_notculp dlose_is_notculp if lowconstraint==0 & democracy==0 & year>1945, efron cluster(ccode)
estat phtest, detail
outreg2 using tableA1, label eform append dec(2)




